# Changelog

<!--next-version-placeholder-->

## v0.6.0 (2022-08-03)
### Feature
* Link matrix back to files ([`06f94ea`](https://gitlab.com/exb/engineering/ticket-cross-check/-/commit/06f94ea55c225824159d30bd38c33ff6c86add68))
* Matrix added, plus navigations ([`7e87e77`](https://gitlab.com/exb/engineering/ticket-cross-check/-/commit/7e87e772676884599bdf36804c13b8a7dacaafb9))
* Matrix added, rendering incomplete ([`a32b5b5`](https://gitlab.com/exb/engineering/ticket-cross-check/-/commit/a32b5b5db26aba6554a892908e9f400992ea236e))

### Fix
* Flake8 ([`551a548`](https://gitlab.com/exb/engineering/ticket-cross-check/-/commit/551a5488a10d3927c05072587171b2bbb8569bee))

## v0.3.1 (2022-08-02)
### Fix
* Remove scm dep from pyproject ([`641aa5d`](https://github.com/exb/engineering/ticket-cross-check/commit/641aa5d3f761c8d295993bc694d57afe82480b28))

## v0.2.0 (2022-08-02)
### Feature
* Add python semantic release ([`5b01a7d`](https://github.com/exb/engineering/ticket-cross-check/commit/5b01a7d39ae53dcaa41c3a468945dfe804cf56c1))
* Run pages ([`564638b`](https://github.com/exb/engineering/ticket-cross-check/commit/564638b84cbc96d452029f822556bb26c22f0bfd))
* Add discover cli script to match issues against multiple dirs ([`b53e86a`](https://github.com/exb/engineering/ticket-cross-check/commit/b53e86ad1fec1d6f5de65bd9578aff2f9827534b))
* Introduced gitlab lib for projet handling ([`5fe32c7`](https://github.com/exb/engineering/ticket-cross-check/commit/5fe32c7a1fdf17816c0b5943c05bda67d0c20080))
* Matcher runs against gitlab and files for given path ([`eeaddc6`](https://github.com/exb/engineering/ticket-cross-check/commit/eeaddc6656c0d154d3e5bf5aedf6467f366ac2de))
* Test for issue analyzer ([`a69d468`](https://github.com/exb/engineering/ticket-cross-check/commit/a69d468ce2f8d5562f4bd5a9bec535ce18545254))
* Add how to disable loguru ([`86061fc`](https://github.com/exb/engineering/ticket-cross-check/commit/86061fc17dd597370942e96214d485b1d4de3c3c))
* Add spec ([`9c69d00`](https://github.com/exb/engineering/ticket-cross-check/commit/9c69d0095436c121a3144505ff5f4db61358aeec))
* Add issue finder and sample data + tests ([`09ac175`](https://github.com/exb/engineering/ticket-cross-check/commit/09ac175004afe5586b02a32f6973b3068ed290b1))
* Add versioning from scm ([`508049d`](https://github.com/exb/engineering/ticket-cross-check/commit/508049d56de6c2ce2db82b697c6bf0d3c7818df9))
* Pdm install and setup infos added to README ([`39b206b`](https://github.com/exb/engineering/ticket-cross-check/commit/39b206b83dac0d442d58ff96f6fa103cd5e0b96f))
* **#1:** Older code adapted to new models, solves #1 ([`1f85740`](https://github.com/exb/engineering/ticket-cross-check/commit/1f857403de9b2191d56ac01c2a55aaeb8ac65404))
* **#1:** Add models and tests ([`29fb763`](https://github.com/exb/engineering/ticket-cross-check/commit/29fb76332d2db23a9f086944bf59e3e617368759))
* Gitlabconnector factory to gain variables from environment ([`4d3e855`](https://github.com/exb/engineering/ticket-cross-check/commit/4d3e855ee5da7f9b53ac125222cc3beb2f705eb7))
* New hidden files to protect from git ([`e3199fb`](https://github.com/exb/engineering/ticket-cross-check/commit/e3199fbbefee3d8a39d4d134215a444880b30fa0))
* Add valid links to badges ([`49bbd5f`](https://github.com/exb/engineering/ticket-cross-check/commit/49bbd5f6a5e874074a99899e2bb945448a7212ff))
* #1 gitlab connector ([`2297824`](https://github.com/exb/engineering/ticket-cross-check/commit/2297824137b1be56275e935878010d3aba5c5ab7))
* Use caching ([`23acc2d`](https://github.com/exb/engineering/ticket-cross-check/commit/23acc2d0598a54ad01af133e284410803a5f5156))
* Badges added ([`69f2ad1`](https://github.com/exb/engineering/ticket-cross-check/commit/69f2ad1c86276d50d2703a6f0082c66bb36499d0))
* New pipeline order ([`56fb6a2`](https://github.com/exb/engineering/ticket-cross-check/commit/56fb6a2fb37985cc7dbbcbdc3726a234aeae0c16))
* Add coverage ([`a025112`](https://github.com/exb/engineering/ticket-cross-check/commit/a02511210aae8d2286eb19a362f82e832bd768ea))
* Enable flake8 ([`954bc99`](https://github.com/exb/engineering/ticket-cross-check/commit/954bc99b2f39c89c308dfb4eabcf122eaaeca2ae))

### Fix
* Set pages output to public ([`4a7b6bd`](https://github.com/exb/engineering/ticket-cross-check/commit/4a7b6bde4e8b4ee9ed5ea5b076903cdf0c05e917))
* Flake8 issues ([`d9398e1`](https://github.com/exb/engineering/ticket-cross-check/commit/d9398e11eaacb4a53123d57465579300fe0558d8))
* Scan_files auto-skips dirs and binary files ([`7a1a77d`](https://github.com/exb/engineering/ticket-cross-check/commit/7a1a77d05f9ca049ac2cc50536825f79abbc4ff7))
* **__init__py:** Style ([`7c41ee3`](https://github.com/exb/engineering/ticket-cross-check/commit/7c41ee349d0bd51d87058543caddae5b4181099f))
* Runtime deps cleanup ([`7427e9b`](https://github.com/exb/engineering/ticket-cross-check/commit/7427e9bb565f5007776be4acc9eddf53ec97d1e9))
* Flake8 ([`ae35d7c`](https://github.com/exb/engineering/ticket-cross-check/commit/ae35d7c5b672dd72e8597a82584d6d8d45a67c55))
* Flake8 missing newline for version file ([`d2eaace`](https://github.com/exb/engineering/ticket-cross-check/commit/d2eaace910966fdb8cfc3ac2954e5da3d3fd5392))
* Do not assume anythong about the parent path (fails on local gitlab-runner) ([`dab3c25`](https://github.com/exb/engineering/ticket-cross-check/commit/dab3c258559c3ab86a9a55ffb9ac2ba55f9fefc9))
* Test_issue_finder dynamic path allocation ([`626a448`](https://github.com/exb/engineering/ticket-cross-check/commit/626a448c95b1f9352e3cd029f10c0330454c8a7b))
* Flake8 ([`769d7cc`](https://github.com/exb/engineering/ticket-cross-check/commit/769d7ccf65358cf6bfe99e8ea7432d9021daef18))
* Test variable used (gc) ([`13440c4`](https://github.com/exb/engineering/ticket-cross-check/commit/13440c48eaaab780154972fcfad1e5a599807d58))
* Flake8 ([`1a41957`](https://github.com/exb/engineering/ticket-cross-check/commit/1a419570710e15e6e23361ea8d7e03ade9b11081))
* Python 3.9 required ([`6e25d80`](https://github.com/exb/engineering/ticket-cross-check/commit/6e25d80cbc28f378fbca73121b83ac00925e8a59))
* Make this a real test ([`cd42077`](https://github.com/exb/engineering/ticket-cross-check/commit/cd42077e8307d311f2c59dd49dc9f6276f01034b))
* Reverted ([`87ff683`](https://github.com/exb/engineering/ticket-cross-check/commit/87ff683beaa77171b09c4b1891261d76177f4e11))
* Add path ([`54910e2`](https://github.com/exb/engineering/ticket-cross-check/commit/54910e2d73feb6ba09d45b71085a5f96c5228d50))
* Add path ([`2362def`](https://github.com/exb/engineering/ticket-cross-check/commit/2362defb058998de5fae8cd5d8d171fcd6a9ce7c))
* Add pdm to cache ([`efe374b`](https://github.com/exb/engineering/ticket-cross-check/commit/efe374b4ae9e69289d998e3879cec3c4b1ea802d))
* Add pdm to cache ([`c80ab46`](https://github.com/exb/engineering/ticket-cross-check/commit/c80ab46b8863d6f9f1580b4efd0c59b170d35724))
* Add debugging ([`dcb34f8`](https://github.com/exb/engineering/ticket-cross-check/commit/dcb34f8123220063dbf0c9b75f06a9d6362a071b))
* Add debugging ([`96fc46d`](https://github.com/exb/engineering/ticket-cross-check/commit/96fc46d90b4e87ac76a85eab18acd31a93118527))
* Add debugging ([`082c328`](https://github.com/exb/engineering/ticket-cross-check/commit/082c328690698d7f916dc04b7aa033685d9a7da8))
* Add before script ([`c777f47`](https://github.com/exb/engineering/ticket-cross-check/commit/c777f47873c552779bf445c94d4352c1ca94629c))
* Intermediate steps not needed for coverage ([`659a7b4`](https://github.com/exb/engineering/ticket-cross-check/commit/659a7b40b44cc49dd787df3fe2303875d8c06ca2))
* Add coverage ([`118353d`](https://github.com/exb/engineering/ticket-cross-check/commit/118353d0e62b7f55a70a3bc9c6a70cacb78ed2f3))
* Add coverage ([`0b61615`](https://github.com/exb/engineering/ticket-cross-check/commit/0b61615931f0d462c9974a88256db3a41e20fbc1))
